<?php
// xxx.php
require_once('config.php');

// Build navigation: find all PHP files (excluding ones with "_content") that have a corresponding _content.php file.
$allPages = glob("*.php");
$pages = array();
foreach ($allPages as $file) {
    if (strpos($file, '_content.php') === false) {
        $base = basename($file, '.php');
        if (file_exists($base . "_content.php")) {
            $pages[] = $base;
        }
    }
}

// Determine current page base name.
$currentFile = basename(__FILE__, '.php');
$baseCurrent = $currentFile;  // Template file is now simply "xxx.php"

// Header height (if header is enabled)
$headerHeight = ($headerEnabled) ? 60 : 0;
?>
<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title><?php echo htmlspecialchars($siteTitle); ?></title>
  <link href="https://fonts.googleapis.com/css2?family=Press+Start+2P&display=swap" rel="stylesheet">
  <style>
    /* Global Styles */
    html, body {
      margin: 0;
      padding: 0;
      height: 100vh;
      font-family: 'Press Start 2P', cursive;
      color: white;
      background: #7F7F7F; /* Use Minecraft stone color as fallback */
      overflow: hidden;
    }
    /* Fixed Header Bar (if enabled) */
    <?php if($headerEnabled): ?>
    #headerBar {
      position: fixed;
      top: 0;
      left: 0;
      width: 100%;
      height: 60px;
      z-index: 100;
      background: url('https://thenathe.me/img/oak_planks.png') repeat;
      box-shadow: 2px 2px 0 #000;
      display: flex;
      align-items: center;
      padding: 0 20px;
    }
    .header-content {
      display: flex;
      align-items: center;
      justify-content: space-between;
      width: 100%;
    }
    .header-left {
      display: flex;
      align-items: center;
    }
    .site-icon {
      width: 40px;
      height: 40px;
      margin-right: 10px;
    }
    .site-title {
      font-size: 20px;
    }
    /* Mobile Menu Toggle Button: Styled like the nav buttons */
    .menu-toggle {
      font-size: 28px;
      background-color: #7F7F7F;
      border: 2px solid #000;
      padding: 5px 10px;
      color: white;
      cursor: pointer;
      display: none;
      margin-right: 5%; /* 5% right margin */
      box-shadow: 2px 2px 0 #000;
    }
    #headerNav {
      display: flex;
      gap: 15px;
      margin-right: 5%; /* 5% right margin */
    }
    #headerNav a {
      background-color: #7F7F7F;
      border: 2px solid #000;
      padding: 5px 10px;
      text-decoration: none;
      color: white;
      font-size: 16px;
      box-shadow: 2px 2px 0 #000;
    }
    #headerNav a:active {
      box-shadow: none;
      transform: translate(2px,2px);
    }
    /* Mobile Styles: collapse menu at 800px */
    @media (max-width: 800px) {
      .menu-toggle {
        display: block;
      }
      #headerNav {
        display: none;
        flex-direction: column;
        position: absolute;
        top: 60px;
        right: 5%;
        background: url('https://thenathe.me/img/oak_planks.png') repeat;
        border: 2px solid #000;
        padding: 10px;
      }
      #headerNav.open {
        display: flex;
      }
    }
    <?php endif; ?>

    /* Background Container: starts below header (or at top if header disabled) */
    #background {
      position: fixed;
      top: <?php echo $headerHeight; ?>px;
      left: 0;
      z-index: 1;
    }
    /* Background Layers */
    #layerSky {
      position: absolute;
      left: 0;
      background: #0099FF;
    }
    #layerGrass, #layerDirt, #layerTransition1, #layerStone, #layerTransition2, #layerDeepslate {
      position: absolute;
      left: 0;
      overflow: hidden;
    }
    /* Lava Container */
    #lavaContainer {
      position: fixed;
      top: <?php echo $headerHeight; ?>px;
      left: 0;
      z-index: 2;
      pointer-events: none;
    }
    /* Scrollable Content Container */
    #scrollContainer {
      position: absolute;
      top: <?php echo $headerHeight; ?>px;
      left: 0;
      width: 100%;
      bottom: 0;
      overflow-y: auto;
      z-index: 3;
    }
    /* Main Content Container */
    #content {
      margin: 20px auto 40px auto;
      width: 70%;
      padding: 20px;
      background: rgba(0,0,0,0.3);
      border: 3px solid #000;
      border-radius: 10px;
    }
  </style>
</head>
<body>
  <?php if($headerEnabled): ?>
  <!-- Header Bar -->
  <div id="headerBar">
    <div class="header-content">
      <div class="header-left">
        <img src="<?php echo htmlspecialchars($siteIcon); ?>" alt="Site Icon" class="site-icon">
        <span class="site-title"><?php echo htmlspecialchars($siteTitle); ?></span>
      </div>
      <button id="menuToggle" class="menu-toggle">&#9776;</button>
      <nav id="headerNav">
        <?php foreach($pages as $page): ?>
          <a href="<?php echo $page . '.php'; ?>"><?php echo ucfirst($page); ?></a>
        <?php endforeach; ?>
      </nav>
    </div>
  </div>
  <?php endif; ?>

  <!-- Background Layers -->
  <div id="background">
    <div class="layer" id="layerSky"></div>
    <div class="layer" id="layerGrass"></div>
    <div class="layer" id="layerDirt"></div>
    <div class="layer" id="layerTransition1"></div>
    <div class="layer" id="layerStone"></div>
    <div class="layer" id="layerTransition2"></div>
    <div class="layer" id="layerDeepslate"></div>
  </div>

  <!-- Lava Container -->
  <div id="lavaContainer"></div>

  <!-- Scrollable Content Container -->
  <div id="scrollContainer">
    <div id="content">
      <?php
      $contentFile = $baseCurrent . "_content.php";
      if (file_exists($contentFile)) {
          include($contentFile);
      } else {
          echo "<p>No content available.</p>";
      }
      ?>
    </div>
  </div>

  <!-- Background Grid Script (IIFE to prevent redeclarations) -->
  <script>
    (function() {
      /*****************************************
       * Adjustable Background Variables Block *
       *****************************************
       * cellSize         : Size (px) of one grid cell.
       * skyRows          : Number of rows for the sky (blue) layer.
       * grassRows        : Number of rows for the grass layer.
       * dirtRows         : Number of rows for the dirt layer.
       * trans1Rows       : Number of rows for the first transition layer.
       * trans2Rows       : Number of rows for the second transition layer.
       *
       * oreChance        : Base chance for a cell to become an ore (if no neighbor).
       * inheritChance    : Chance to inherit a neighbor's ore.
       *
       * caveRegionSize   : Number of cells in one cave region.
       * cavesPerSection  : Number of cave regions to insert per section.
       * caveDarkness     : Brightness factor for cave cells (e.g., 0.40 means 40% brightness).
       *
       * lavaClustersPerSection : Number of lava clusters per section.
       * lavaClusterMinSize     : Minimum cells in a lava cluster.
       * lavaClusterMaxSize     : Maximum cells in a lava cluster.
       ******************************************/
      var cellSize = <?php echo json_encode($cellSize); ?>;
      var skyRows = <?php echo json_encode($skyRows); ?>;
      var grassRows = <?php echo json_encode($grassRows); ?>;
      var dirtRows = <?php echo json_encode($dirtRows); ?>;
      var trans1Rows = <?php echo json_encode($trans1Rows); ?>;
      var trans2Rows = <?php echo json_encode($trans2Rows); ?>;
      var oreChance = <?php echo json_encode($oreChance); ?>;
      var inheritChance = <?php echo json_encode($inheritChance); ?>;
      var caveRegionSize = <?php echo json_encode($caveRegionSize); ?>;
      var cavesPerSection = <?php echo json_encode($cavesPerSection); ?>;
      var caveDarkness = <?php echo json_encode($caveDarkness); ?>;
      var lavaClustersPerSection = <?php echo json_encode($lavaClustersPerSection); ?>;
      var lavaClusterMinSize = <?php echo json_encode($lavaClusterMinSize); ?>;
      var lavaClusterMaxSize = <?php echo json_encode($lavaClusterMaxSize); ?>;

      // Derived grid variables:
      var winWidth = window.innerWidth;
      var winHeight = window.innerHeight;
      var cols = Math.ceil(winWidth / cellSize);
      // Use (cols+1) to help cover extra space and hide seams.
      var fixedHeight = cellSize * (skyRows + grassRows + dirtRows + trans1Rows + trans2Rows);
      var remaining = winHeight - fixedHeight;
      var stoneAndDeepslateHeight = Math.floor(remaining / (2 * cellSize)) * cellSize;
      var stoneRows = stoneAndDeepslateHeight / cellSize;
      var deepslateRows = stoneRows;

      // Get background layer elements:
      var layerSky = document.getElementById('layerSky');
      var layerGrass = document.getElementById('layerGrass');
      var layerDirt = document.getElementById('layerDirt');
      var layerTransition1 = document.getElementById('layerTransition1');
      var layerStone = document.getElementById('layerStone');
      var layerTransition2 = document.getElementById('layerTransition2');
      var layerDeepslate = document.getElementById('layerDeepslate');

      // Set dynamic layer heights and positions:
      layerSky.style.height = (skyRows * cellSize) + "px";
      layerSky.style.top = "0px";
      layerSky.style.width = ((cols + 1) * cellSize) + "px";

      layerGrass.style.height = (grassRows * cellSize) + "px";
      layerGrass.style.top = (skyRows * cellSize) + "px";

      layerDirt.style.height = (dirtRows * cellSize) + "px";
      layerDirt.style.top = ((skyRows + grassRows) * cellSize) + "px";

      layerTransition1.style.height = (trans1Rows * cellSize) + "px";
      layerTransition1.style.top = ((skyRows + grassRows + dirtRows) * cellSize) + "px";

      layerStone.style.height = (stoneRows * cellSize) + "px";
      layerStone.style.top = ((skyRows + grassRows + dirtRows + trans1Rows) * cellSize) + "px";

      layerTransition2.style.height = (trans2Rows * cellSize) + "px";
      layerTransition2.style.top = (((skyRows + grassRows + dirtRows + trans1Rows) * cellSize) + stoneRows * cellSize) + "px";

      layerDeepslate.style.height = (deepslateRows * cellSize) + "px";
      layerDeepslate.style.top = (((skyRows + grassRows + dirtRows + trans1Rows) * cellSize) + stoneRows * cellSize + trans2Rows * cellSize) + "px";

      // Function: Generate a grid layer using a texture function.
      function generateGrid(layerElement, rows, cols, textureFunc) {
        layerElement.innerHTML = "";
        layerElement.style.width = ((cols + 1) * cellSize) + "px";
        for (var r = 0; r < rows; r++) {
          for (var c = 0; c < cols; c++) {
            var cell = document.createElement('div');
            cell.style.position = "absolute";
            cell.style.width = cellSize + "px";
            cell.style.height = cellSize + "px";
            cell.style.left = (c * cellSize) + "px";
            cell.style.top = (r * cellSize) + "px";
            cell.style.backgroundImage = "url('" + textureFunc(r, c) + "')";
            cell.style.backgroundSize = "100% 100%";
            layerElement.appendChild(cell);
          }
        }
      }

      // Function: Generate a grid from a 2D array.
      // caveCoords: Object with keys "r,c" for cells to darken.
      function generateGridFromArray(layerElement, grid, caveCoords) {
        caveCoords = caveCoords || {};
        layerElement.innerHTML = "";
        var rows = grid.length;
        var cols = grid[0].length;
        layerElement.style.width = ((cols + 1) * cellSize) + "px";
        for (var r = 0; r < rows; r++) {
          for (var c = 0; c < cols; c++) {
            var cell = document.createElement('div');
            cell.style.position = "absolute";
            cell.style.width = cellSize + "px";
            cell.style.height = cellSize + "px";
            cell.style.left = (c * cellSize) + "px";
            cell.style.top = (r * cellSize) + "px";
            cell.style.backgroundImage = "url('" + grid[r][c] + "')";
            cell.style.backgroundSize = "100% 100%";
            if (caveCoords[r + "," + c]) {
              cell.style.filter = "brightness(" + (caveDarkness * 100) + "%)";
            }
            layerElement.appendChild(cell);
          }
        }
      }

      // Texture functions:
      var grassTexture = function() { return 'https://thenathe.me/img/grass.png'; };
      var dirtTexture = function() { return 'https://thenathe.me/img/dirt.png'; };
      var trans1Texture = function() { return (Math.random() < 0.5 ? 'https://thenathe.me/img/dirt.png' : 'https://thenathe.me/img/stone.png'); };
      var trans2Texture = function() { return (Math.random() < 0.5 ? 'https://thenathe.me/img/stone.png' : 'https://thenathe.me/img/deepslate.png'); };

      // Function: Generate an ore grid.
      function generateOreGrid(rows, cols, baseTexture, oreSet) {
        var grid = [];
        for (var r = 0; r < rows; r++) {
          grid[r] = [];
          for (var c = 0; c < cols; c++) {
            var newVal = baseTexture;
            if (Math.random() < oreChance) {
              newVal = oreSet[Math.floor(Math.random() * oreSet.length)];
            } else {
              var leftOre = (c > 0 && grid[r][c-1] !== baseTexture) ? grid[r][c-1] : null;
              var topOre = (r > 0 && grid[r-1][c] !== baseTexture) ? grid[r-1][c] : null;
              if (leftOre || topOre) {
                if (Math.random() < inheritChance) {
                  newVal = (Math.random() < 0.5 && leftOre) ? leftOre : (topOre || leftOre);
                }
              }
            }
            grid[r][c] = newVal;
          }
        }
        return grid;
      }

      // Function: Insert a cave region by recording cell coordinates.
      function insertCave(grid, caveSize) {
        var rows = grid.length;
        var cols = grid[0].length;
        var caveCoords = {};
        var startRow = Math.floor(Math.random() * rows);
        var startCol = Math.floor(Math.random() * cols);
        caveCoords[startRow + "," + startCol] = true;
        var caveCells = [{ r: startRow, c: startCol }];
        while (caveCells.length < caveSize) {
          var cell = caveCells[Math.floor(Math.random() * caveCells.length)];
          var neighbors = [];
          if (cell.r > 0) neighbors.push({ r: cell.r - 1, c: cell.c });
          if (cell.r < rows - 1) neighbors.push({ r: cell.r + 1, c: cell.c });
          if (cell.c > 0) neighbors.push({ r: cell.r, c: cell.c - 1 });
          if (cell.c < cols - 1) neighbors.push({ r: cell.r, c: cell.c + 1 });
          neighbors = neighbors.filter(function(n) { return !caveCoords[n.r + "," + n.c]; });
          if (neighbors.length === 0) break;
          var chosen = neighbors[Math.floor(Math.random() * neighbors.length)];
          caveCoords[chosen.r + "," + chosen.c] = true;
          caveCells.push(chosen);
        }
        return caveCoords;
      }

      // Generate fixed background layers:
      generateGrid(document.getElementById('layerGrass'), grassRows, cols, grassTexture);
      generateGrid(document.getElementById('layerDirt'), dirtRows, cols, dirtTexture);
      generateGrid(document.getElementById('layerTransition1'), trans1Rows, cols, trans1Texture);
      generateGrid(document.getElementById('layerTransition2'), trans2Rows, cols, trans2Texture);

      // Generate ore grids for stone and deepslate:
      var stoneOreSet = [
        'https://thenathe.me/img/copper_ore.png',
        'https://thenathe.me/img/coal_ore.png',
        'https://thenathe.me/img/iron_ore.png'
      ];
      var stoneGrid = generateOreGrid(stoneRows, cols, 'https://thenathe.me/img/stone.png', stoneOreSet);
      var caveCoordsStone = {};
      for (var i = 0; i < cavesPerSection; i++) {
        Object.assign(caveCoordsStone, insertCave(stoneGrid, caveRegionSize));
      }
      generateGridFromArray(layerStone, stoneGrid, caveCoordsStone);

      var deepslateOreSet = [
        'https://thenathe.me/img/diamond_ore.png',
        'https://thenathe.me/img/gold_ore.png',
        'https://thenathe.me/img/redstone_ore.png'
      ];
      var deepslateGrid = generateOreGrid(deepslateRows, cols, 'https://thenathe.me/img/deepslate.png', deepslateOreSet);
      var caveCoordsDeepslate = {};
      for (var i = 0; i < cavesPerSection; i++) {
        Object.assign(caveCoordsDeepslate, insertCave(deepslateGrid, caveRegionSize));
      }
      generateGridFromArray(layerDeepslate, deepslateGrid, caveCoordsDeepslate);

      // Generate lava clusters:
      function generateLavaCluster(layerElement) {
        var rect = layerElement.getBoundingClientRect();
        var layerCols = Math.floor(rect.width / cellSize);
        var layerRows = Math.floor(rect.height / cellSize);
        if (layerCols <= 0 || layerRows <= 0) return;
        var clusterSize = Math.floor(Math.random() * (lavaClusterMaxSize - lavaClusterMinSize + 1)) + lavaClusterMinSize;
        var cluster = [];
        var start = { col: Math.floor(Math.random() * layerCols), row: Math.floor(Math.random() * layerRows) };
        cluster.push(start);
        while (cluster.length < clusterSize) {
          var base = cluster[Math.floor(Math.random() * cluster.length)];
          var d;
          var r = Math.floor(Math.random() * 8);
          if (r < 3) {
            d = { dc: -1, dr: 0 };
          } else if (r < 6) {
            d = { dc: 1, dr: 0 };
          } else if (r === 6) {
            d = { dc: 0, dr: -1 };
          } else {
            d = { dc: 0, dr: 1 };
          }
          var newCol = base.col + d.dc;
          var newRow = base.row + d.dr;
          if (newCol >= 0 && newCol < layerCols && newRow >= 0 && newRow < layerRows &&
              !cluster.some(function(cell) { return cell.col === newCol && cell.row === newRow; })) {
            cluster.push({ col: newCol, row: newRow });
          }
        }
        var lavaContainer = document.getElementById('lavaContainer');
        cluster.forEach(function(cell) {
          var lava = document.createElement('img');
          lava.src = 'https://thenathe.me/img/lava.png';
          lava.style.position = "absolute";
          lava.style.width = cellSize + "px";
          lava.style.height = cellSize + "px";
          lava.style.left = (rect.left + cell.col * cellSize) + "px";
          lava.style.top = (rect.top + cell.row * cellSize) + "px";
          lavaContainer.appendChild(lava);
        });
      }
      for (var i = 0; i < lavaClustersPerSection; i++) {
        generateLavaCluster(layerStone);
        generateLavaCluster(layerDeepslate);
      }

      // Scale the background to fit the screen.
      function scaleBackground() {
        var bg = document.getElementById('background');
        var lavaCont = document.getElementById('lavaContainer');
        var gridWidth = (cols + 1) * cellSize;
        var gridHeight = fixedHeight + (stoneRows + deepslateRows) * cellSize;
        var scaleFactor = Math.max(window.innerWidth / gridWidth, window.innerHeight / gridHeight);
        bg.style.transform = "scale(" + scaleFactor + ")";
        bg.style.transformOrigin = "top left";
        lavaCont.style.transform = "scale(" + scaleFactor + ")";
        lavaCont.style.transformOrigin = "top left";
      }
      scaleBackground();
      window.addEventListener('resize', scaleBackground);
    })();
  </script>

  <!-- Mobile Menu Toggle Script -->
  <script>
    const menuToggle = document.getElementById('menuToggle');
    const headerNav = document.getElementById('headerNav');
    menuToggle.addEventListener('click', () => {
      headerNav.classList.toggle('open');
    });
  </script>
</body>
</html>
