<style>
  #topbar {
      display: flex;
      justify-content: flex-start;
      margin-bottom: 10px;
  }
  /* Controls use the same font */
  button, #search {
      font-family: 'Press Start 2P', cursive;
  }
  button {
      background-color: #7F7F7F;
      color: white;
      border: 2px solid #000;
      padding: 10px 20px;
      cursor: pointer;
      box-shadow: 2px 2px 0 #000;
      margin-right: 10px;
  }
  button:active {
      box-shadow: none;
      transform: translate(2px,2px);
  }
  h1 {
      text-align: center;
      margin-bottom: 20px;
      font-size: 24px;
  }
  #search {
      width: 100%;
      max-width: 400px;
      padding: 8px;
      margin-bottom: 20px;
      border: 2px solid #000;
      box-shadow: 2px 2px 0 #000;
      background-color: #333;
      color: white;
      font-size: 14px;
  }
  /* Item List styling using CSS Grid with fixed columns */
  .item-list {
      list-style: none;
      padding: 0;
      margin: 0;
  }
  .item-list li {
      font-size: 12px;
  }
  /* New column order: Display Name, Stack Size, ID, Identifier */
  .header-row, .item-row {
      display: grid;
      grid-template-columns: 20fr 8fr 5fr 20fr;
      border: 2px solid #000;
      background: rgba(0,0,0,0.5);
      padding: 10px;
      margin: 5px 0;
      align-items: center;
      text-align: left;
  }
  .header-row {
      font-weight: bold;
      background: rgba(0,0,0,0.7);
      cursor: default;
  }
  .item-row {
      cursor: pointer;
  }
  .item-row:hover {
      background: rgba(0,0,0,0.7);
  }
  /* Updated class for identifier column: breaks long words */
  .item-identifier {
      overflow-wrap: break-word;
      word-break: break-all;
      white-space: normal;
  }
  #jsonNote {
      text-align: center;
      font-size: 12px;
      margin-top: 20px;
  }
  #jsonNote a {
      color: #FFD700;
      text-decoration: none;
  }
  /* Media query for smaller screens */
  @media (max-width: 600px) {
      .item-list li {
          font-size: 10px;
      }
      h1 {
          font-size: 18px;
      }
  }
</style>

<div id="topbar">
  <button onclick="window.history.back()">Go Back</button>
</div>
<h1>Minecraft Items</h1>
<input type="text" id="search" placeholder="Search items...">
<ul class="item-list" id="itemList"></ul>
<p id="jsonNote">
  For the full item list, see 
  <a href="https://github.com/PrismarineJS/minecraft-data/blob/master/data/pc/1.21.4/items.json" target="_blank">
    this URL
  </a>.
</p>

<!-- Search & Item List Script -->
<script>
  let itemsData = [];
  fetch('items.json')
    .then(response => response.json())
    .then(data => {
      itemsData = data;
      renderItems();
    })
    .catch(error => console.error("Error loading items.json:", error));

  const itemList = document.getElementById('itemList');
  const searchInput = document.getElementById('search');

  function copyToClipboard(text) {
    navigator.clipboard.writeText(text);
  }

  function renderItems(filter = "") {
    itemList.innerHTML = "";
    // Create header row with 4 columns: Display Name, Stack Size, ID, Identifier
    const header = document.createElement('li');
    header.className = "header-row";
    header.style.cursor = "default";
    
    const headerDisplay = document.createElement('span');
    headerDisplay.textContent = "Display Name";
    
    const headerStack = document.createElement('span');
    headerStack.textContent = "Stack Size";
    
    const headerId = document.createElement('span');
    headerId.textContent = "ID";
    
    const headerIdent = document.createElement('span');
    headerIdent.textContent = "Identifier";
    
    header.appendChild(headerDisplay);
    header.appendChild(headerStack);
    header.appendChild(headerId);
    header.appendChild(headerIdent);
    itemList.appendChild(header);
    
    const lowerFilter = filter.toLowerCase();
    const filtered = itemsData.filter(item => {
      const idStr = String(item.id);
      return idStr.includes(lowerFilter) ||
             (item.name && item.name.toLowerCase().includes(lowerFilter)) ||
             (item.displayName && item.displayName.toLowerCase().includes(lowerFilter));
    });
    
    filtered.forEach(item => {
      const li = document.createElement('li');
      li.className = "item-row";
      li.style.cursor = "pointer";
      // Entire row clickable: copy "minecraft:" + item.name
      li.addEventListener('click', () => copyToClipboard("minecraft:" + item.name));
      
      const spanDisplay = document.createElement('span');
      spanDisplay.textContent = item.displayName || item.name;
      
      const spanStack = document.createElement('span');
      spanStack.textContent = item.stackSize;
      
      const spanId = document.createElement('span');
      spanId.textContent = item.id;
      
      const spanIdent = document.createElement('span');
      spanIdent.textContent = "minecraft:" + item.name;
      spanIdent.className = "item-identifier";
      
      li.appendChild(spanDisplay);
      li.appendChild(spanStack);
      li.appendChild(spanId);
      li.appendChild(spanIdent);
      itemList.appendChild(li);
    });
  }

  searchInput.addEventListener('input', function() {
    renderItems(this.value);
  });

  renderItems();
</script>
