<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8">
  <title>Minecraft Items</title>
  <link href="https://fonts.googleapis.com/css2?family=Press+Start+2P&display=swap" rel="stylesheet">
  <style>
    /* Global Styles */
    html, body {
      margin: 0;
      padding: 0;
      height: 100vh;
      font-family: 'Press Start 2P', cursive;
      color: white;
      overflow: hidden;
      background: black;
    }
    /* Background layer containers */
    .layer {
      position: absolute;
      left: 0;
      overflow: hidden;
    }
    /* Fixed layers (multiples of 32px) */
    #layerGrass { top: 0; height: 32px; }
    #layerDirt  { top: 32px; height: 128px; }
    #layerTransition1 { top: 160px; height: 32px; }
    /* Stone, Transition2, and Deepslate will be set dynamically */
    #layerStone { top: 192px; }
    #layerTransition2 { }
    #layerDeepslate { }
    /* Lava container: above background layers but below content */
    #lavaContainer {
      position: absolute;
      top: 0;
      left: 0;
      z-index: 2;
      pointer-events: none;
    }
    /* Content container (on top) */
    #content {
      position: relative;
      z-index: 3;
      margin: 20px auto;
      width: 70%;  /* 70% of screen width */
      padding: 20px;
      background: rgba(0,0,0,0.3);
      border: 3px solid #000;
      border-radius: 10px;
    }
    #topbar {
      display: flex;
      justify-content: flex-start;
      margin-bottom: 10px;
    }
    /* Controls use the same font */
    button, #search {
      font-family: 'Press Start 2P', cursive;
    }
    button {
      background-color: #7F7F7F;
      color: white;
      border: 2px solid #000;
      padding: 10px 20px;
      cursor: pointer;
      box-shadow: 2px 2px 0 #000;
      margin-right: 10px;
    }
    button:active {
      box-shadow: none;
      transform: translate(2px,2px);
    }
    h1 {
      text-align: center;
      margin-bottom: 20px;
      font-size: 24px;
    }
    #search {
      width: 100%;
      max-width: 400px;
      padding: 8px;
      margin-bottom: 20px;
      border: 2px solid #000;
      box-shadow: 2px 2px 0 #000;
      background-color: #333;
      color: white;
      font-size: 14px;
    }
    /* Item List styling using CSS Grid with fixed columns */
    .item-list {
      list-style: none;
      padding: 0;
      margin: 0;
    }
    .item-list li {
      font-size: 12px;
    }
    /* New column order: Display Name, Stack Size, ID, Identifier */
    .header-row, .item-row {
      display: grid;
      grid-template-columns: 20fr 8fr 5fr 20fr;
      border: 2px solid #000;
      background: rgba(0,0,0,0.5);
      padding: 10px;
      margin: 5px 0;
      align-items: center;
      text-align: left;
    }
    .header-row {
      font-weight: bold;
      background: rgba(0,0,0,0.7);
      cursor: default;
    }
    .item-row {
      cursor: pointer;
    }
    .item-row:hover {
      background: rgba(0,0,0,0.7);
    }
    #jsonNote {
      text-align: center;
      font-size: 12px;
      margin-top: 20px;
    }
    #jsonNote a {
      color: #FFD700;
      text-decoration: none;
    }
  </style>
</head>
<body>
  <!-- Background layers container -->
  <div id="background">
    <div class="layer" id="layerGrass"></div>
    <div class="layer" id="layerDirt"></div>
    <div class="layer" id="layerTransition1"></div>
    <div class="layer" id="layerStone"></div>
    <div class="layer" id="layerTransition2"></div>
    <div class="layer" id="layerDeepslate"></div>
  </div>
  
  <!-- Lava container -->
  <div id="lavaContainer"></div>
  
  <!-- Content container -->
  <div id="content">
    <div id="topbar">
      <button onclick="window.history.back()">Go Back</button>
    </div>
    <h1>Minecraft Items</h1>
    <input type="text" id="search" placeholder="Search items...">
    <ul class="item-list" id="itemList"></ul>
    <p id="jsonNote">
      For the full item list, see 
      <a href="https://github.com/PrismarineJS/minecraft-data/blob/master/data/pc/1.21.4/items.json" target="_blank">
        this URL
      </a>.
    </p>
  </div>
  
  <!-- Background Grid Script -->
  <script>
    /* Adjustable Background Variables */
    const cellSize = 32;           // Grid cell size (32px x 32px)
    const grassRows = 1;           // Number of rows for the grass layer
    const dirtRows = 4;            // Number of rows for the dirt layer
    const trans1Rows = 1;          // Number of rows for the first transition layer
    const trans2Rows = 1;          // Number of rows for the second transition layer

    const oreChance = 0.05;        // Base chance (if no neighbor) for a cell to become an ore (5%)
    const inheritChance = 0.40;    // Chance to inherit a neighbor's ore if one exists (40%)

    const caveRegionSize = 60;     // Cave region size: number of cells per cave region
    const cavesPerSection = 1;     // Number of caves to insert per section (stone & deepslate)
    const caveDarkness = 0.40;     // Cave cells are rendered at 40% brightness (i.e. 60% darker)

    const lavaClustersPerSection = 1;   // Number of lava clusters per section
    const lavaClusterMinSize = 10;        // Minimum cells in a lava cluster
    const lavaClusterMaxSize = 15;        // Maximum cells in a lava cluster

    // Derived grid variables:
    const winWidth = window.innerWidth;
    const winHeight = window.innerHeight;
    const cols = Math.ceil(winWidth / cellSize);  // Number of columns to fill width
    const fixedHeight = cellSize * (grassRows + dirtRows + trans1Rows + trans2Rows);  // Fixed vertical height from fixed layers
    const remaining = winHeight - fixedHeight;
    const stoneAndDeepslateHeight = Math.floor(remaining / (2 * cellSize)) * cellSize;
    const stoneRows = stoneAndDeepslateHeight / cellSize;
    const deepslateRows = stoneRows;

    // Get background layer elements:
    const layerStone = document.getElementById('layerStone');
    const layerTransition2 = document.getElementById('layerTransition2');
    const layerDeepslate = document.getElementById('layerDeepslate');

    // Set dynamic layer heights and positions:
    layerStone.style.height = (stoneRows * cellSize) + "px";
    layerStone.style.top = (cellSize * (grassRows + dirtRows + trans1Rows)) + "px";
    layerTransition2.style.height = (cellSize * trans2Rows) + "px";
    layerTransition2.style.top = (cellSize * (grassRows + dirtRows + trans1Rows) + stoneRows * cellSize) + "px";
    layerDeepslate.style.height = (deepslateRows * cellSize) + "px";
    layerDeepslate.style.top = (cellSize * (grassRows + dirtRows + trans1Rows) + stoneRows * cellSize + cellSize) + "px";

    // Function to generate a grid layer from a texture function.
    function generateGrid(layerElement, rows, cols, textureFunc) {
      layerElement.innerHTML = "";
      layerElement.style.width = (cols * cellSize) + "px";
      for (let r = 0; r < rows; r++) {
        for (let c = 0; c < cols; c++) {
          const cell = document.createElement('div');
          cell.style.position = "absolute";
          cell.style.width = cellSize + "px";
          cell.style.height = cellSize + "px";
          cell.style.left = (c * cellSize) + "px";
          cell.style.top = (r * cellSize) + "px";
          cell.style.backgroundImage = "url('" + textureFunc(r, c) + "')";
          cell.style.backgroundSize = "cover";
          layerElement.appendChild(cell);
        }
      }
    }

    // Function to generate a grid from a precomputed 2D array.
    // caveCoords is an object with keys "r,c" for cells that should appear darker.
    function generateGridFromArray(layerElement, grid, caveCoords = {}) {
      layerElement.innerHTML = "";
      const rows = grid.length;
      const cols = grid[0].length;
      layerElement.style.width = (cols * cellSize) + "px";
      for (let r = 0; r < rows; r++) {
        for (let c = 0; c < cols; c++) {
          const cell = document.createElement('div');
          cell.style.position = "absolute";
          cell.style.width = cellSize + "px";
          cell.style.height = cellSize + "px";
          cell.style.left = (c * cellSize) + "px";
          cell.style.top = (r * cellSize) + "px";
          cell.style.backgroundImage = "url('" + grid[r][c] + "')";
          cell.style.backgroundSize = "cover";
          if (caveCoords[`${r},${c}`]) {
            cell.style.filter = `brightness(${caveDarkness * 100}%)`;
          }
          layerElement.appendChild(cell);
        }
      }
    }

    // Texture functions for the fixed layers:
    const grassTexture = () => 'https://thenathe.me/img/grass.png';
    const dirtTexture  = () => 'https://thenathe.me/img/dirt.png';
    const trans1Texture = () => (Math.random() < 0.5 ? 'https://thenathe.me/img/dirt.png' : 'https://thenathe.me/img/stone.png');
    const trans2Texture = () => (Math.random() < 0.5 ? 'https://thenathe.me/img/stone.png' : 'https://thenathe.me/img/deepslate.png');

    // Function to generate an ore grid.
    function generateOreGrid(rows, cols, baseTexture, oreSet) {
      let grid = [];
      for (let r = 0; r < rows; r++) {
        grid[r] = [];
        for (let c = 0; c < cols; c++) {
          let newVal = baseTexture;
          if (Math.random() < oreChance) {
            newVal = oreSet[Math.floor(Math.random() * oreSet.length)];
          } else {
            let leftOre = (c > 0 && grid[r][c-1] !== baseTexture) ? grid[r][c-1] : null;
            let topOre = (r > 0 && grid[r-1][c] !== baseTexture) ? grid[r-1][c] : null;
            if (leftOre || topOre) {
              if (Math.random() < inheritChance) {
                newVal = (Math.random() < 0.5 && leftOre) ? leftOre : (topOre || leftOre);
              }
            }
          }
          grid[r][c] = newVal;
        }
      }
      return grid;
    }

    // Cave insertion: instead of removing blocks, record coordinates to apply a darkness filter.
    function insertCave(grid, caveSize) {
      const rows = grid.length;
      const cols = grid[0].length;
      let caveCoords = {};
      const startRow = Math.floor(Math.random() * rows);
      const startCol = Math.floor(Math.random() * cols);
      caveCoords[`${startRow},${startCol}`] = true;
      let caveCells = [{ r: startRow, c: startCol }];
      while (caveCells.length < caveSize) {
        const cell = caveCells[Math.floor(Math.random() * caveCells.length)];
        let neighbors = [];
        if (cell.r > 0) neighbors.push({ r: cell.r - 1, c: cell.c });
        if (cell.r < rows - 1) neighbors.push({ r: cell.r + 1, c: cell.c });
        if (cell.c > 0) neighbors.push({ r: cell.r, c: cell.c - 1 });
        if (cell.c < cols - 1) neighbors.push({ r: cell.r, c: cell.c + 1 });
        neighbors = neighbors.filter(n => !caveCoords[`${n.r},${n.c}`]);
        if (neighbors.length === 0) break;
        const chosen = neighbors[Math.floor(Math.random() * neighbors.length)];
        caveCoords[`${chosen.r},${chosen.c}`] = true;
        caveCells.push(chosen);
      }
      return caveCoords;
    }

    // Generate fixed background layers:
    generateGrid(document.getElementById('layerGrass'), grassRows, cols, grassTexture);
    generateGrid(document.getElementById('layerDirt'), dirtRows, cols, dirtTexture);
    generateGrid(document.getElementById('layerTransition1'), trans1Rows, cols, trans1Texture);
    generateGrid(document.getElementById('layerTransition2'), trans2Rows, cols, trans2Texture);

    // Generate ore grids for stone and deepslate:
    const stoneOreSet = [
      'https://thenathe.me/img/copper_ore.png',
      'https://thenathe.me/img/coal_ore.png',
      'https://thenathe.me/img/iron_ore.png'
    ];
    let stoneGrid = generateOreGrid(stoneRows, cols, 'https://thenathe.me/img/stone.png', stoneOreSet);
    let caveCoordsStone = {};
    for (let i = 0; i < cavesPerSection; i++) {
      Object.assign(caveCoordsStone, insertCave(stoneGrid, caveRegionSize));
    }
    generateGridFromArray(layerStone, stoneGrid, caveCoordsStone);

    const deepslateOreSet = [
      'https://thenathe.me/img/diamond_ore.png',
      'https://thenathe.me/img/gold_ore.png',
      'https://thenathe.me/img/redstone_ore.png'
    ];
    let deepslateGrid = generateOreGrid(deepslateRows, cols, 'https://thenathe.me/img/deepslate.png', deepslateOreSet);
    let caveCoordsDeepslate = {};
    for (let i = 0; i < cavesPerSection; i++) {
      Object.assign(caveCoordsDeepslate, insertCave(deepslateGrid, caveRegionSize));
    }
    generateGridFromArray(layerDeepslate, deepslateGrid, caveCoordsDeepslate);

    // Modified lava cluster generation: uses adjustable lava cluster size range.
    function generateLavaCluster(layerElement) {
      const rect = layerElement.getBoundingClientRect();
      const layerCols = Math.floor(rect.width / cellSize);
      const layerRows = Math.floor(rect.height / cellSize);
      if (layerCols <= 0 || layerRows <= 0) return;
      const clusterSize = Math.floor(Math.random() * (lavaClusterMaxSize - lavaClusterMinSize + 1)) + lavaClusterMinSize;
      const cluster = [];
      const start = { col: Math.floor(Math.random() * layerCols), row: Math.floor(Math.random() * layerRows) };
      cluster.push(start);
      while (cluster.length < clusterSize) {
        const base = cluster[Math.floor(Math.random() * cluster.length)];
        let d;
        const r = Math.floor(Math.random() * 8);
        if (r < 3) {
          d = { dc: -1, dr: 0 };
        } else if (r < 6) {
          d = { dc: 1, dr: 0 };
        } else if (r === 6) {
          d = { dc: 0, dr: -1 };
        } else {
          d = { dc: 0, dr: 1 };
        }
        const newCol = base.col + d.dc;
        const newRow = base.row + d.dr;
        if (newCol >= 0 && newCol < layerCols && newRow >= 0 && newRow < layerRows &&
            !cluster.some(cell => cell.col === newCol && cell.row === newRow)) {
          cluster.push({ col: newCol, row: newRow });
        }
      }
      const lavaContainer = document.getElementById('lavaContainer');
      cluster.forEach(cell => {
        const lava = document.createElement('img');
        lava.src = 'https://thenathe.me/img/lava.png';
        lava.style.position = "absolute";
        lava.style.width = cellSize + "px";
        lava.style.height = cellSize + "px";
        lava.style.left = (rect.left + cell.col * cellSize) + "px";
        lava.style.top = (rect.top + cell.row * cellSize) + "px";
        lavaContainer.appendChild(lava);
      });
    }

    // Generate adjustable number of lava clusters per section:
    for (let i = 0; i < lavaClustersPerSection; i++) {
      generateLavaCluster(layerStone);
      generateLavaCluster(layerDeepslate);
    }

    // Scale background to fit the screen:
    function scaleBackground() {
      const bg = document.getElementById('background');
      const lavaCont = document.getElementById('lavaContainer');
      const gridWidth = cols * cellSize;
      const gridHeight = 224 + (stoneRows + deepslateRows) * cellSize;
      const scaleFactor = Math.max(window.innerWidth / gridWidth, window.innerHeight / gridHeight);
      bg.style.transform = `scale(${scaleFactor})`;
      bg.style.transformOrigin = "top left";
      lavaCont.style.transform = `scale(${scaleFactor})`;
      lavaCont.style.transformOrigin = "top left";
    }
    scaleBackground();
    window.addEventListener('resize', scaleBackground);
  </script>
  
  <!-- Search & Item List Script -->
  <script>
    let itemsData = [];
    fetch('items.json')
      .then(response => response.json())
      .then(data => {
        itemsData = data;
        renderItems();
      })
      .catch(error => console.error("Error loading items.json:", error));

    const itemList = document.getElementById('itemList');
    const searchInput = document.getElementById('search');

    function copyToClipboard(text) {
      navigator.clipboard.writeText(text);
    }

    function renderItems(filter = "") {
      itemList.innerHTML = "";
      // Create header row with 4 columns: Display Name, Stack Size, ID, Identifier
      const header = document.createElement('li');
      header.className = "header-row";
      header.style.cursor = "default";
      
      const headerDisplay = document.createElement('span');
      headerDisplay.textContent = "Display Name";
      
      const headerStack = document.createElement('span');
      headerStack.textContent = "Stack Size";
      
      const headerId = document.createElement('span');
      headerId.textContent = "ID";
      
      const headerIdent = document.createElement('span');
      headerIdent.textContent = "Identifier";
      
      header.appendChild(headerDisplay);
      header.appendChild(headerStack);
      header.appendChild(headerId);
      header.appendChild(headerIdent);
      itemList.appendChild(header);
      
      const lowerFilter = filter.toLowerCase();
      const filtered = itemsData.filter(item => {
        const idStr = String(item.id);
        return idStr.includes(lowerFilter) ||
               (item.name && item.name.toLowerCase().includes(lowerFilter)) ||
               (item.displayName && item.displayName.toLowerCase().includes(lowerFilter));
      });
      
      filtered.forEach(item => {
        const li = document.createElement('li');
        li.className = "item-row";
        li.style.cursor = "pointer";
        // Entire row clickable: copy "minecraft:" + item.name
        li.addEventListener('click', () => copyToClipboard("minecraft:" + item.name));
        
        const spanDisplay = document.createElement('span');
        spanDisplay.textContent = item.displayName || item.name;
        
        const spanStack = document.createElement('span');
        spanStack.textContent = item.stackSize;
        
        const spanId = document.createElement('span');
        spanId.textContent = item.id;
        
        const spanIdent = document.createElement('span');
        spanIdent.textContent = "minecraft:" + item.name;
        
        li.appendChild(spanDisplay);
        li.appendChild(spanStack);
        li.appendChild(spanId);
        li.appendChild(spanIdent);
        itemList.appendChild(li);
      });
    }

    searchInput.addEventListener('input', function() {
      renderItems(this.value);
    });

    renderItems();
  </script>
</body>
</html>
